summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/oscar/icq/icqaccount.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/oscar/icq/icqaccount.cpp')
-rw-r--r--kopete/protocols/oscar/icq/icqaccount.cpp46
1 files changed, 23 insertions, 23 deletions
diff --git a/kopete/protocols/oscar/icq/icqaccount.cpp b/kopete/protocols/oscar/icq/icqaccount.cpp
index 7e358346..e9772233 100644
--- a/kopete/protocols/oscar/icq/icqaccount.cpp
+++ b/kopete/protocols/oscar/icq/icqaccount.cpp
@@ -50,9 +50,9 @@ ICQMyselfContact::ICQMyselfContact( ICQAccount *acct ) : OscarMyselfContact( acc
void ICQMyselfContact::userInfoUpdated()
{
- DWORD extendedStatus = details().extendedStatus();
- kdDebug( OSCAR_ICQ_DEBUG ) << k_funcinfo << "extendedStatus is " << TQString::number( extendedStatus, 16 ) << endl;
- ICQ::Presence presence = ICQ::Presence::fromOscarStatus( extendedStatus & 0xffff );
+ DWORD extendedtqStatus = details().extendedtqStatus();
+ kdDebug( OSCAR_ICQ_DEBUG ) << k_funcinfo << "extendedtqStatus is " << TQString::number( extendedtqStatus, 16 ) << endl;
+ ICQ::Presence presence = ICQ::Presence::fromOscartqStatus( extendedtqStatus & 0xffff );
setOnlineStatus( presence.toOnlineStatus() );
setProperty( Kopete::Global::Properties::self()->awayMessage(), static_cast<ICQAccount*>( account() )->engine()->statusMessage() );
}
@@ -74,8 +74,8 @@ void ICQMyselfContact::fetchShortInfo()
static_cast<ICQAccount*>( account() )->engine()->requestShortInfo( contactId() );
}
-ICQAccount::ICQAccount(Kopete::Protocol *parent, TQString accountID, const char *name)
- : OscarAccount(parent, accountID, name, true)
+ICQAccount::ICQAccount(Kopete::Protocol *tqparent, TQString accountID, const char *name)
+ : OscarAccount(tqparent, accountID, name, true)
{
kdDebug(14152) << k_funcinfo << accountID << ": Called."<< endl;
setMyself( new ICQMyselfContact( this ) );
@@ -83,10 +83,10 @@ ICQAccount::ICQAccount(Kopete::Protocol *parent, TQString accountID, const char
m_visibilityDialog = 0;
- TQString nickName = configGroup()->readEntry("NickName", TQString::null);
+ TQString nickName = configGroup()->readEntry("NickName", TQString());
mWebAware = configGroup()->readBoolEntry( "WebAware", false );
mHideIP = configGroup()->readBoolEntry( "HideIP", true );
- mInitialStatusMessage = TQString::null;
+ mInitialStatusMessage = TQString();
TQObject::connect( Kopete::ContactList::self(), TQT_SIGNAL( globalIdentityChanged( const TQString&, const TQVariant& ) ),
this, TQT_SLOT( slotGlobalIdentityChanged( const TQString&, const TQVariant& ) ) );
@@ -100,7 +100,7 @@ ICQAccount::ICQAccount(Kopete::Protocol *parent, TQString accountID, const char
{
kdDebug(14153) << k_funcinfo <<
"sending status to reflect HideIP and WebAware settings" << endl;
- //setStatus(mStatus, TQString::null);
+ //settqStatus(mtqStatus, TQString());
}*/
}
@@ -116,7 +116,7 @@ ICQProtocol* ICQAccount::protocol()
ICQ::Presence ICQAccount::presence()
{
- return ICQ::Presence::fromOnlineStatus( myself()->onlineStatus() );
+ return ICQ::Presence::fromOnlineStatus( myself()->onlinetqStatus() );
}
@@ -150,21 +150,21 @@ void ICQAccount::connectWithPassword( const TQString &password )
kdDebug(14153) << k_funcinfo << "accountId='" << accountId() << "'" << endl;
- Kopete::OnlineStatus status = initialStatus();
+ Kopete::OnlineStatus status = initialtqStatus();
if ( status == Kopete::OnlineStatus() &&
status.status() == Kopete::OnlineStatus::Unknown )
//use default online in case of invalid online status for connecting
status = Kopete::OnlineStatus( Kopete::OnlineStatus::Online );
ICQ::Presence pres = ICQ::Presence::fromOnlineStatus( status );
bool accountIsOffline = ( presence().type() == ICQ::Presence::Offline ||
- myself()->onlineStatus() == protocol()->statusManager()->connectingStatus() );
+ myself()->onlinetqStatus() == protocol()->statusManager()->connectingtqStatus() );
if ( accountIsOffline )
{
- myself()->setOnlineStatus( protocol()->statusManager()->connectingStatus() );
+ myself()->setOnlineStatus( protocol()->statusManager()->connectingtqStatus() );
TQString icqNumber = accountId();
kdDebug(14153) << k_funcinfo << "Logging in as " << icqNumber << endl ;
- TQString server = configGroup()->readEntry( "Server", TQString::fromLatin1( "login.oscar.aol.com" ) );
+ TQString server = configGroup()->readEntry( "Server", TQString::tqfromLatin1( "login.oscar.aol.com" ) );
uint port = configGroup()->readNumEntry( "Port", 5190 );
Connection* c = setupConnection( server, port );
@@ -172,20 +172,20 @@ void ICQAccount::connectWithPassword( const TQString &password )
Oscar::Settings* oscarSettings = engine()->clientSettings();
oscarSettings->setWebAware( configGroup()->readBoolEntry( "WebAware", false ) );
oscarSettings->setHideIP( configGroup()->readBoolEntry( "HideIP", true ) );
- //FIXME: also needed for the other call to setStatus (in setPresenceTarget)
- DWORD status = pres.toOscarStatus();
+ //FIXME: also needed for the other call to settqStatus (in setPresenceTarget)
+ DWORD status = pres.toOscartqStatus();
if ( !mHideIP )
status |= ICQ::StatusCode::SHOWIP;
if ( mWebAware )
status |= ICQ::StatusCode::WEBAWARE;
- engine()->setStatus( status, mInitialStatusMessage );
+ engine()->settqStatus( status, mInitialStatusMessage );
updateVersionUpdaterStamp();
engine()->start( server, port, accountId(), password );
engine()->connectToServer( c, server, true /* doAuth */ );
- mInitialStatusMessage = TQString::null;
+ mInitialStatusMessage = TQString();
}
}
@@ -250,7 +250,7 @@ void ICQAccount::slotSetVisiblility()
if ( oc )
{ //for better orientation in lists use nickName and icq number
TQString screenName( "%1 (%2)" );
- screenName = screenName.arg( oc->nickName(), contactId);
+ screenName = screenName.tqarg( oc->nickName(), contactId);
contactMap.insert( screenName, contactId );
revContactMap.insert( contactId, screenName );
}
@@ -331,7 +331,7 @@ void ICQAccount::setPresenceTarget( const ICQ::Presence &newPres, const TQString
{
bool targetIsOffline = (newPres.type() == ICQ::Presence::Offline);
bool accountIsOffline = ( presence().type() == ICQ::Presence::Offline ||
- myself()->onlineStatus() == protocol()->statusManager()->connectingStatus() );
+ myself()->onlinetqStatus() == protocol()->statusManager()->connectingtqStatus() );
if ( targetIsOffline )
{
@@ -346,7 +346,7 @@ void ICQAccount::setPresenceTarget( const ICQ::Presence &newPres, const TQString
}
else
{
- engine()->setStatus( newPres.toOscarStatus(), message );
+ engine()->settqStatus( newPres.toOscartqStatus(), message );
}
}
@@ -375,9 +375,9 @@ void ICQAccount::setOnlineStatus( const Kopete::OnlineStatus& status, const TQSt
}
-OscarContact *ICQAccount::createNewContact( const TQString &contactId, Kopete::MetaContact *parentContact, const SSI& ssiItem )
+OscarContact *ICQAccount::createNewContact( const TQString &contactId, Kopete::MetaContact *tqparentContact, const SSI& ssiItem )
{
- ICQContact* contact = new ICQContact( this, contactId, parentContact, TQString::null, ssiItem );
+ ICQContact* contact = new ICQContact( this, contactId, tqparentContact, TQString(), ssiItem );
if ( !ssiItem.alias().isEmpty() )
contact->setProperty( Kopete::Global::Properties::self()->nickName(), ssiItem.alias() );
@@ -457,7 +457,7 @@ void ICQAccount::slotBuddyIconChanged()
iconFile.open( IO_ReadOnly );
KMD5 iconHash;
- iconHash.update( iconFile );
+ iconHash.update( *TQT_TQIODEVICE(&iconFile) );
kdDebug(14153) << k_funcinfo << "hash is :" << iconHash.hexDigest() << endl;
//find old item, create updated item